package com.jqtx.windows.common.mq;

import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.jqtx.infrastructure.mq.starter.annotation.MQConsumerComponent;
import com.jqtx.infrastructure.oss.starter.config.OssUtils;
import com.jqtx.windows.common.mq.model.CreditResultModel;
import com.jqtx.windows.component.CreditComponent;
import com.jqtx.windows.component.LoanComponent;
import com.jqtx.windows.component.enums.CreditResultStatusEnum;
import com.jqtx.windows.component.enums.ZNPostUrlEnum;
import com.jqtx.windows.component.model.CreditModel;
import com.jqtx.windows.component.model.LoanModel;
import com.jqtx.windows.utils.AbcHttpClient;
import com.jqtx.windows.web.response.WithdrawDetailResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;

import java.time.LocalDateTime;

/**
 * 提现审核结果
 */
@Slf4j
@MQConsumerComponent(tags = "creditThirdData", topic = "$mq.creditTopic")
public class CreditThirdDataListener extends AbstractMQConsumerHandler<JSONObject> {

    @Autowired
    private LoanComponent loanComponent;
    @Autowired
    private AbcHttpClient abcHttpClient;
    @Autowired
    private OssUtils ossUtils ;
    @Autowired
    private CreditComponent creditComponent;

    @Override
    public Class getClazz() {
        return JSONObject.class;
    }

    @Override
    public void run(JSONObject req) throws Exception {

        String orderNo=req.getString("orderNo");
        String loanNo=  req.getString("loanNo");
        if(StringUtils.isNotEmpty(orderNo)&& StringUtils.isEmpty(loanNo)){
            credit(orderNo);
        }else{
            withdraw(orderNo,loanNo);
        }
    }

    private void credit(String orderNo) {
        CreditModel creditModel= creditComponent.getByOrderNo(orderNo);
        if(creditModel!=null&& creditModel.getCreditThirdStatus()!="INIT"){
            JSONObject thirdCredit = new JSONObject();
            thirdCredit.put("reqNo", orderNo);
            thirdCredit.put("type", "01");
            abcHttpClient.postRequest(thirdCredit.toJSONString(), ZNPostUrlEnum.CREDIT_APPLY.getCode());
            CreditModel creditModel1=new CreditModel();
            creditModel1.setCreditThirdStatus("INIT");
            creditModel1.setCreditThirdUrl("");
            creditComponent.updateByOrderNo(orderNo,creditModel1);
        }
    }

    private void withdraw(String orderNo,String loanNo) {
        CreditModel creditModel= creditComponent.getByOrderNo(orderNo);
        if(creditModel!=null&& creditModel.getCreditThirdStatus()!="INIT-WITHDRAW"){
            JSONObject thirdCredit = new JSONObject();
            thirdCredit.put("reqNo", loanNo);
            thirdCredit.put("type", "02");
            abcHttpClient.postRequest(thirdCredit.toJSONString(), ZNPostUrlEnum.CREDIT_APPLY.getCode());
            CreditModel creditModel1=new CreditModel();
            creditModel1.setCreditThirdStatus("INIT-WITHDRAW");
            creditModel1.setCreditThirdUrl("");
            creditComponent.updateByOrderNo(orderNo,creditModel1);
        }
    }
}

